==> ameegos_1.0.0.tar.gz: ameegos-1.0.0/wnew.cpp <==
#include "wnew.h"
#include "ui_wnew.h"
#include <QDebug>


WNew::WNew(QWidget *parent) :
    QWidget(parent),
    ui(new Ui::WNew)
{
    ui->setupUi(this);

    imgMouth = new QLabel(this);
    imgMouth->setPixmap(QPixmap(":/icons/Mouth/mouth-1.png"));
    imgMouth->setGeometry(218,385,110,50);

    imgEyes = new QLabel(this);
    imgEyes->setPixmap(QPixmap(":/icons/Eyes/Eye-5.png"));
    imgEyes->setGeometry(200,310,110,50);


    headIndex = 0;
    eyesIndex = 0;
    mouthIndex = 0;

    mouths.append(":/icons/Mouth/mouth-1.png");
    mouths.append(":/icons/Mouth/mouth-2.png");
    mouths.append(":/icons/Mouth/mouth-3.png");
    mouths.append(":/icons/Mouth/mouth-4.png");
    mouths.append(":/icons/Mouth/mouth-5.png");
    mouths.append(":/icons/Mouth/mouth-6.png");
    mouths.append(":/icons/Mouth/mouth-7.png");
    mouths.append(":/icons/Mouth/mouth-8.png");
    mouths.append(":/icons/Mouth/mouth-9.png");
    mouths.append(":/icons/Mouth/mouth-10.png");
    mouths.append(":/icons/Mouth/mouth-11.png");
    mouths.append(":/icons/Mouth/mouth-12.png");
    mouths.append(":/icons/Mouth/mouth-13.png");

    eyes.append(":/icons/Eyes/Eye-5.png");
    eyes.append(":/icons/Eyes/Eye-1.png");
    eyes.append(":/icons/Eyes/Eye-2.png");
    eyes.append(":/icons/Eyes/Eye-3.png");
    eyes.append(":/icons/Eyes/Eye-4.png");
    eyes.append(":/icons/Eyes/Eye-6.png");
    eyes.append(":/icons/Eyes/Eye-7.png");
    eyes.append(":/icons/Eyes/Eye-8.png");
    eyes.append(":/icons/Eyes/Eye-9.png");
    eyes.append(":/icons/Eyes/Eye-10.png");
    eyes.append(":/icons/Eyes/Eye-11.png");
    eyes.append(":/icons/Eyes/Eye-12.png");
    eyes.append(":/icons/Eyes/Eye-13.png");
    eyes.append(":/icons/Eyes/Eye-14.png");
    eyes.append(":/icons/Eyes/Eye-15.png");
    eyes.append(":/icons/Eyes/Eye-16.png");
    eyes.append(":/icons/Eyes/Eye-17.png");
    eyes.append(":/icons/Eyes/Eye-18.png");
    eyes.append(":/icons/Eyes/Eye-19.png");
    eyes.append(":/icons/Eyes/Eye-20.png");
    eyes.append(":/icons/Eyes/Eye-21.png");
    eyes.append(":/icons/Eyes/Eye-22.png");
    eyes.append(":/icons/Eyes/Eye-23.png");
    eyes.append(":/icons/Eyes/Eye-24.png");
    eyes.append(":/icons/Eyes/Eye-25.png");
    eyes.append(":/icons/Eyes/Eye-26.png");
    eyes.append(":/icons/Eyes/Eye-27.png");
    eyes.append(":/icons/Eyes/Eye-28.png");
    eyes.append(":/icons/Eyes/Eye-29.png");

    heads.append(":/icons/Head/Lime-1.png");
    heads.append(":/icons/Head/Lime-2.png");

    heads.append(":/icons/Head/Black-1.png");
    heads.append(":/icons/Head/Black-2.png");

    heads.append(":/icons/Head/Blue-1.png");
    heads.append(":/icons/Head/Blue-2.png");

    heads.append(":/icons/Head/Brown-1.png");
    heads.append(":/icons/Head/Brown-2.png");

    heads.append(":/icons/Head/Gray-1.png");
    heads.append(":/icons/Head/Gray-2.png");

    heads.append(":/icons/Head/Green-1.png");
    heads.append(":/icons/Head/Green-2.png");

    heads.append(":/icons/Head/LightBlue-1.png");
    heads.append(":/icons/Head/LightBlue-2.png");

    heads.append(":/icons/Head/LightBrown-1.png");
    heads.append(":/icons/Head/LightBrown-2.png");

    heads.append(":/icons/Head/LightOrange-1.png");
    heads.append(":/icons/Head/LightOrange-2.png");

    heads.append(":/icons/Head/LightPurple-1.png");
    heads.append(":/icons/Head/LightPurple-2.png");

    heads.append(":/icons/Head/Orange-1.png");
    heads.append(":/icons/Head/Orange-2.png");

    heads.append(":/icons/Head/Purple-1.png");
    heads.append(":/icons/Head/Purple-2.png");

    heads.append(":/icons/Head/Red-1.png");
    heads.append(":/icons/Head/Red-2.png");

    heads.append(":/icons/Head/White-1.png");
    heads.append(":/icons/Head/White-2.png");

    heads.append(":/icons/Head/Yellow-1.png");
    heads.append(":/icons/Head/Yellow-2.png");


}

WNew::~WNew()
{
    delete ui;
    delete imgEyes;
    delete imgMouth;
}



void WNew::on_btnHeadRight_clicked(){
    if (headIndex+1>=heads.count()){
	headIndex=0;
    }else{
	headIndex=headIndex+1;
    }

    ui->imgHead->setPixmap(QPixmap(heads.at(headIndex)));

    if (headIndex % 2 == 0){
	imgMouth->setGeometry(imgMouth->x(),imgMouth->y()+13,imgMouth->width(),imgMouth->height());
	imgEyes->setGeometry(imgEyes->x(),imgEyes->y()-7,imgEyes->width(),imgEyes->height());
    } else{
	imgMouth->setGeometry(imgMouth->x(),imgMouth->y()-13,imgMouth->width(),imgMouth->height());
	imgEyes->setGeometry(imgEyes->x(),imgEyes->y()+7,imgEyes->width(),imgEyes->height());
    }
}

void WNew::on_btnHeadLeft_clicked(){
    if (headIndex-1<0){
	headIndex=heads.count()-1;
    }else{
	headIndex=headIndex-1;
    }

    ui->imgHead->setPixmap(QPixmap(heads.at(headIndex)));

    if (headIndex % 2 == 0){
	imgMouth->setGeometry(imgMouth->x(),imgMouth->y()+13,imgMouth->width(),imgMouth->height());
	imgEyes->setGeometry(imgEyes->x(),imgEyes->y()-7,imgEyes->width(),imgEyes->height());
    } else{
	imgMouth->setGeometry(imgMouth->x(),imgMouth->y()-13,imgMouth->width(),imgMouth->height());
	imgEyes->setGeometry(imgEyes->x(),imgEyes->y()+7,imgEyes->width(),imgEyes->height());
    }
}

void WNew::on_btnEyesLeft_clicked(){
    if (eyesIndex+1>=eyes.count()){
	eyesIndex=0;
    }else{
	eyesIndex=eyesIndex+1;
    }

    imgEyes->setPixmap(QPixmap(eyes.at(eyesIndex)));

}

void WNew::on_btnEyesRight_clicked(){
    if (eyesIndex-1<0){
	eyesIndex=eyes.count()-1;
    }else{
	eyesIndex=eyesIndex-1;
    }

    imgEyes->setPixmap(QPixmap(eyes.at(eyesIndex)));
}

void WNew::on_btnMouthRight_clicked(){
    if (mouthIndex+1>=mouths.count()){
	mouthIndex=0;
    }else{
	mouthIndex=mouthIndex+1;
    }
    imgMouth->setPixmap(QPixmap(mouths.at(mouthIndex)));
}

void WNew::on_btnMouthLeft_clicked(){
    if (mouthIndex-1<0){
	mouthIndex=mouths.count()-1;
    }else{
	mouthIndex=mouthIndex-1;
    }
    imgMouth->setPixmap(QPixmap(mouths.at(mouthIndex)));
}

void WNew::on_btnEyesRight_pressed(){
    ui->btnEyesRight->setStyleSheet("border-image: url(:/icons/btnRedRight.png);");
}

void WNew::on_btnEyesRight_released(){
    ui->btnEyesRight->setStyleSheet("border-image: url(:/icons/btnBlackRight.png);");
}

void WNew::on_btnEyesLeft_pressed(){
    ui->btnEyesLeft->setStyleSheet("border-image: url(:/icons/btnRedLeft.png);");
}

void WNew::on_btnEyesLeft_released(){
    ui->btnEyesLeft->setStyleSheet("border-image: url(:/icons/btnBlackLeft.png);");
}

void WNew::on_btnHeadLeft_pressed(){
    ui->btnHeadLeft->setStyleSheet("border-image: url(:/icons/btnRedLeft.png);");
}

void WNew::on_btnHeadLeft_released(){
    ui->btnHeadLeft->setStyleSheet("border-image: url(:/icons/btnBlackLeft.png);");
}

void WNew::on_btnHeadRight_pressed(){
    ui->btnHeadRight->setStyleSheet("border-image: url(:/icons/btnRedRight.png);");
}

void WNew::on_btnHeadRight_released(){
    ui->btnHeadRight->setStyleSheet("border-image: url(:/icons/btnBlackRight.png);");
}

void WNew::on_btnMouthLeft_pressed(){
    ui->btnMouthLeft->setStyleSheet("border-image: url(:/icons/btnRedLeft.png);");
}

void WNew::on_btnMouthLeft_released(){
    ui->btnMouthLeft->setStyleSheet("border-image: url(:/icons/btnBlackLeft.png);");
}

void WNew::on_btnMouthRight_pressed(){
    ui->btnMouthRight->setStyleSheet("border-image: url(:/icons/btnRedRight.png);");
}

void WNew::on_btnMouthRight_released(){
    ui->btnMouthRight->setStyleSheet("border-image: url(:/icons/btnBlackRight.png);");
}

==> ameegos_1.1.1.tar.gz: ameegos-1.1.1/wnew.cpp <==
#include "wnew.h"
#include "ui_wnew.h"
#include <QDebug>


WNew::WNew(QWidget *parent) :
    QWidget(parent),
    ui(new Ui::WNew)
{
    ui->setupUi(this);

    imgMouth = new QLabel(this);
    imgMouth->setPixmap(QPixmap(":/icons/Mouth/mouth-1.png"));
    imgMouth->setGeometry(218,385,110,50);

#ifdef Q_WS_MAEMO_5
    imgMouth->setGeometry(218,355,110,50);
#endif

    imgEyes = new QLabel(this);
    imgEyes->setPixmap(QPixmap(":/icons/Eyes/Eye-5.png"));
    imgEyes->setGeometry(200,310,110,50);

#ifdef Q_WS_MAEMO_5
    imgEyes->setGeometry(200,280,110,50);
#endif


    headIndex = 0;
    eyesIndex = 0;
    mouthIndex = 0;

    mouths.append(":/icons/Mouth/mouth-1.png");
    mouths.append(":/icons/Mouth/mouth-2.png");
    mouths.append(":/icons/Mouth/mouth-3.png");
    mouths.append(":/icons/Mouth/mouth-4.png");
    mouths.append(":/icons/Mouth/mouth-5.png");
    mouths.append(":/icons/Mouth/mouth-6.png");
    mouths.append(":/icons/Mouth/mouth-7.png");
    mouths.append(":/icons/Mouth/mouth-8.png");
    mouths.append(":/icons/Mouth/mouth-9.png");
    mouths.append(":/icons/Mouth/mouth-10.png");
    mouths.append(":/icons/Mouth/mouth-11.png");
    mouths.append(":/icons/Mouth/mouth-12.png");
    mouths.append(":/icons/Mouth/mouth-13.png");

    eyes.append(":/icons/Eyes/Eye-5.png");
    eyes.append(":/icons/Eyes/Eye-1.png");
    eyes.append(":/icons/Eyes/Eye-2.png");
    eyes.append(":/icons/Eyes/Eye-3.png");
    eyes.append(":/icons/Eyes/Eye-4.png");
    eyes.append(":/icons/Eyes/Eye-6.png");
    eyes.append(":/icons/Eyes/Eye-7.png");
    eyes.append(":/icons/Eyes/Eye-8.png");
    eyes.append(":/icons/Eyes/Eye-9.png");
    eyes.append(":/icons/Eyes/Eye-10.png");
    eyes.append(":/icons/Eyes/Eye-11.png");
    eyes.append(":/icons/Eyes/Eye-12.png");
    eyes.append(":/icons/Eyes/Eye-13.png");
    eyes.append(":/icons/Eyes/Eye-14.png");
    eyes.append(":/icons/Eyes/Eye-15.png");
    eyes.append(":/icons/Eyes/Eye-16.png");
    eyes.append(":/icons/Eyes/Eye-17.png");
    eyes.append(":/icons/Eyes/Eye-18.png");
    eyes.append(":/icons/Eyes/Eye-19.png");
    eyes.append(":/icons/Eyes/Eye-20.png");
    eyes.append(":/icons/Eyes/Eye-21.png");
    eyes.append(":/icons/Eyes/Eye-22.png");
    eyes.append(":/icons/Eyes/Eye-23.png");
    eyes.append(":/icons/Eyes/Eye-24.png");
    eyes.append(":/icons/Eyes/Eye-25.png");
    eyes.append(":/icons/Eyes/Eye-26.png");
    eyes.append(":/icons/Eyes/Eye-27.png");
    eyes.append(":/icons/Eyes/Eye-28.png");
    eyes.append(":/icons/Eyes/Eye-29.png");

    heads.append(":/icons/Head/Lime-1.png");
    heads.append(":/icons/Head/Lime-2.png");

    heads.append(":/icons/Head/Black-1.png");
    heads.append(":/icons/Head/Black-2.png");

    heads.append(":/icons/Head/Blue-1.png");
    heads.append(":/icons/Head/Blue-2.png");

    heads.append(":/icons/Head/Brown-1.png");
    heads.append(":/icons/Head/Brown-2.png");

    heads.append(":/icons/Head/Gray-1.png");
    heads.append(":/icons/Head/Gray-2.png");

    heads.append(":/icons/Head/Green-1.png");
    heads.append(":/icons/Head/Green-2.png");

    heads.append(":/icons/Head/LightBlue-1.png");
    heads.append(":/icons/Head/LightBlue-2.png");

    heads.append(":/icons/Head/LightBrown-1.png");
    heads.append(":/icons/Head/LightBrown-2.png");

    heads.append(":/icons/Head/LightOrange-1.png");
    heads.append(":/icons/Head/LightOrange-2.png");

    heads.append(":/icons/Head/LightPurple-1.png");
    heads.append(":/icons/Head/LightPurple-2.png");

    heads.append(":/icons/Head/Orange-1.png");
    heads.append(":/icons/Head/Orange-2.png");

    heads.append(":/icons/Head/Purple-1.png");
    heads.append(":/icons/Head/Purple-2.png");

    heads.append(":/icons/Head/Red-1.png");
    heads.append(":/icons/Head/Red-2.png");

    heads.append(":/icons/Head/White-1.png");
    heads.append(":/icons/Head/White-2.png");

    heads.append(":/icons/Head/Yellow-1.png");
    heads.append(":/icons/Head/Yellow-2.png");

    QRect screenGeometry = QApplication::desktop()->screenGeometry();
    if (screenGeometry.width() > screenGeometry.height()){
	imgMouth->setGeometry(328,215,110,50);
	imgEyes->setGeometry(315,130,110,50);
    }else{
    }

}

WNew::~WNew()
{
    delete ui;
    delete imgEyes;
    delete imgMouth;
}



void WNew::on_btnHeadRight_clicked(){
    if (headIndex+1>=heads.count()){
	headIndex=0;
    }else{
	headIndex=headIndex+1;
    }

    ui->imgHead->setPixmap(QPixmap(heads.at(headIndex)));

    if (headIndex % 2 == 0){
	imgMouth->setGeometry(imgMouth->x(),imgMouth->y()+13,imgMouth->width(),imgMouth->height());
	imgEyes->setGeometry(imgEyes->x(),imgEyes->y()-7,imgEyes->width(),imgEyes->height());
    } else{
	imgMouth->setGeometry(imgMouth->x(),imgMouth->y()-13,imgMouth->width(),imgMouth->height());
	imgEyes->setGeometry(imgEyes->x(),imgEyes->y()+7,imgEyes->width(),imgEyes->height());
    }
}

void WNew::on_btnHeadLeft_clicked(){
    if (headIndex-1<0){
	headIndex=heads.count()-1;
    }else{
	headIndex=headIndex-1;
    }

    ui->imgHead->setPixmap(QPixmap(heads.at(headIndex)));

    if (headIndex % 2 == 0){
	imgMouth->setGeometry(imgMouth->x(),imgMouth->y()+13,imgMouth->width(),imgMouth->height());
	imgEyes->setGeometry(imgEyes->x(),imgEyes->y()-7,imgEyes->width(),imgEyes->height());
    } else{
	imgMouth->setGeometry(imgMouth->x(),imgMouth->y()-13,imgMouth->width(),imgMouth->height());
	imgEyes->setGeometry(imgEyes->x(),imgEyes->y()+7,imgEyes->width(),imgEyes->height());
    }
}

void WNew::on_btnEyesLeft_clicked(){
    if (eyesIndex+1>=eyes.count()){
	eyesIndex=0;
    }else{
	eyesIndex=eyesIndex+1;
    }

    imgEyes->setPixmap(QPixmap(eyes.at(eyesIndex)));

}

void WNew::on_btnEyesRight_clicked(){
    if (eyesIndex-1<0){
	eyesIndex=eyes.count()-1;
    }else{
	eyesIndex=eyesIndex-1;
    }

    imgEyes->setPixmap(QPixmap(eyes.at(eyesIndex)));
}

void WNew::on_btnMouthRight_clicked(){
    if (mouthIndex+1>=mouths.count()){
	mouthIndex=0;
    }else{
	mouthIndex=mouthIndex+1;
    }
    imgMouth->setPixmap(QPixmap(mouths.at(mouthIndex)));
}

void WNew::on_btnMouthLeft_clicked(){
    if (mouthIndex-1<0){
	mouthIndex=mouths.count()-1;
    }else{
	mouthIndex=mouthIndex-1;
    }
    imgMouth->setPixmap(QPixmap(mouths.at(mouthIndex)));
}

void WNew::reorderUI(){
#ifdef Q_WS_MAEMO_5
    QRect screenGeometry = QApplication::desktop()->screenGeometry();
    if (screenGeometry.width() > screenGeometry.height()){
	//Landscape Mode
	imgMouth->setGeometry(333,195,110,50);
	imgEyes->setGeometry(315,130,110,50);
    }
    else{
	//Portrait Mode
	imgMouth->setGeometry(218,355,110,50);
	imgEyes->setGeometry(200,280,110,50);
    }
#endif
}

void WNew::on_btnEyesRight_pressed(){
    ui->btnEyesRight->setStyleSheet("border-image: url(:/icons/btnRedRight.png);");
}

void WNew::on_btnEyesRight_released(){
    ui->btnEyesRight->setStyleSheet("border-image: url(:/icons/btnBlackRight.png);");
}

void WNew::on_btnEyesLeft_pressed(){
    ui->btnEyesLeft->setStyleSheet("border-image: url(:/icons/btnRedLeft.png);");
}

void WNew::on_btnEyesLeft_released(){
    ui->btnEyesLeft->setStyleSheet("border-image: url(:/icons/btnBlackLeft.png);");
}

void WNew::on_btnHeadLeft_pressed(){
    ui->btnHeadLeft->setStyleSheet("border-image: url(:/icons/btnRedLeft.png);");
}

void WNew::on_btnHeadLeft_released(){
    ui->btnHeadLeft->setStyleSheet("border-image: url(:/icons/btnBlackLeft.png);");
}

void WNew::on_btnHeadRight_pressed(){
    ui->btnHeadRight->setStyleSheet("border-image: url(:/icons/btnRedRight.png);");
}

void WNew::on_btnHeadRight_released(){
    ui->btnHeadRight->setStyleSheet("border-image: url(:/icons/btnBlackRight.png);");
}

void WNew::on_btnMouthLeft_pressed(){
    ui->btnMouthLeft->setStyleSheet("border-image: url(:/icons/btnRedLeft.png);");
}

void WNew::on_btnMouthLeft_released(){
    ui->btnMouthLeft->setStyleSheet("border-image: url(:/icons/btnBlackLeft.png);");
}

void WNew::on_btnMouthRight_pressed(){
    ui->btnMouthRight->setStyleSheet("border-image: url(:/icons/btnRedRight.png);");
}

void WNew::on_btnMouthRight_released(){
    ui->btnMouthRight->setStyleSheet("border-image: url(:/icons/btnBlackRight.png);");
}

void WNew::on_btnSave_clicked()
{

}
